# -*- coding: utf-8 -*-
# *******************************************************
#   ____                     _               _
#  / ___|___  _ __ ___   ___| |_   _ __ ___ | |
# | |   / _ \| '_ ` _ \ / _ \ __| | '_ ` _ \| |
# | |__| (_) | | | | | |  __/ |_ _| | | | | | |
#  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
#
#  Sign up for free at http://www.comet.ml
#  Copyright (C) 2015-2021 Comet ML INC
#  This file can not be copied and/or distributed without the express
#  permission of Comet ML Inc.
# *******************************************************

"""

This module contains reporting constants for Comet

"""

EXPERIMENT_CREATED = "experiment_created"

EXPERIMENT_CREATION_FAILED = "experiment_creation_failed"

EXPERIMENT_CREATION_DURATION = "experiment_creation_duration"

FILE_UPLOADED_FAILED = "file_uploaded_failed"

ON_EXIT_DIDNT_FINISH_UPLOAD_SDK = "on_exit_didnt_finish_upload_sdk"

GIT_PATCH_GENERATION_FAILED = "git_patch_generation_failed"

WS_ON_OPEN = "ws_on_open"

WS_ON_ERROR = "ws_on_error"

WS_ON_CLOSE = "ws_on_close"

OFFLINE_INVALID_WS_MSG = "offline_invalid_ws_msg"

OFFLINE_INVALID_UPLOAD_MSG = "offline_invalid_upload_msg"

OFFLINE_INVALID_METRIC_MSG = "offline_invalid_metric_msg"

OFFLINE_INVALID_PARAMETER_MSG = "offline_invalid_parameter_msg"

OFFLINE_INVALID_OS_PACKAGES_MSG = "offline_invalid_os_packages_msg"

OFFLINE_INVALID_GRAPH_MSG = "offline_invalid_graph_msg"

OFFLINE_INVALID_SYSTEM_DETAILS_MSG = "offline_invalid_system_details_msg"

OFFLINE_INVALID_CLOUD_DETAILS_MSG = "offline_invalid_cloud_details_msg"

OFFLINE_INVALID_FILE_NAME_MSG = "offline_invalid_file_name_msg"
